<p align=center>
    <img src="https://img.shields.io/circleci/build/github/kkent030315/twitcasting-py/main?style=for-the-badge">
    <img src="https://img.shields.io/pypi/v/twitcasting-py?style=for-the-badge">
    <img src="https://img.shields.io/github/license/kkent030315/twitcasting-py?style=for-the-badge">
</p>

# twitcasting-py
An unofficial python module for wrapping TwitCasting common APIs

# Usage

1. Install

```bash
pip install twitcasting_py
```

2. Import

```python
import twitcasting
```

3. Use

```python3
twitcasting.get_video_id('user_id')
```

# License

MIT